\name{Cramer}
\alias{pcramer}
\title{The Cramer-von Mises Distribution}
\description{
  Distribution function of the Cramer-von Mises distribution.
}
\usage{
  pcramer(q, eps)
}
\arguments{
  \item{q}{vector of quantiles.}
  \item{eps}{accuracy required}
}
\value{
  \code{pcramer} gives the distribution function,
}
\references{
Anderson TW. and Darling DA. Asymptotic theory of certain `goodness
of fit' criteria based on stochastic processes.  \emph{Ann. Math.
Statist.}, \bold{23}, 192-212 (1952).

Csorgo S. and Faraway, JJ. The exact and asymptotic distributions of
the Cramer-von Mises statistic.  J. Roy. Stat. Soc. (B), \bold{58},
221-234 (1996).
}

\keyword{distribution}


\eof
\name{as.ts.mcmc}
\alias{as.ts.mcmc}
\title{Coerce mcmc object to time series}

\usage{as.ts.mcmc(x)}

\arguments{
   \item{x}{an mcmc object}
}

\description{
\code{as.ts.mcmc} will coerce an mcmc object to a time series.}

\note{
This is pretending to be an \code{as.ts} method for mcmc objects. But
\code{as.ts} is not generic.}

\author{Martyn Plummer}

\seealso{
\code{\link{as.ts}}
}
\keyword{ts}
\keyword{utilities}

\eof
\name{autocorr}
\alias{autocorr}
\title{Autocorrelation function for Markov chains}

\usage{autocorr(mcmc.obj, lags = c(0, 1, 5, 10, 50), relative=TRUE }

\description{
\code{autocorr} calculates the autocorrelation function for the
Markov chain \code{mcmc.obj} at the lags given by \code{lags}.
The lag values are taken to be relative to the thinning interval
if \code{relative=TRUE}.

High autocorrelations within chains indicate slow mixing and, usually,
slow convergence. It may be useful to thin out a chain with high
autocorrelations before calculating summary statistics: a thinned
chain may contain most of the information, but take up less space in
memory. Re-running the MCMC sampler with a different parameterization
may help to reduce autocorrelation.
}

\value{
A vector or array containing the autocorrelations.
}

\author{Martyn Plummer}

\seealso{
\code{\link{acf}}, \code{\link{autocorr.plot}}.}
}
\keyword{ts}

\eof
\name{autocorr.plot}
\alias{autocorr.plot}
\title{Plot autocorrelations for Markov Chains}

\usage{autocorr.plot(x, lag.max, auto.layout = TRUE, ask=TRUE, ...)}

\arguments{
\item{x}{A Markov Chain}
\item{lag.max}{Maximum value at which to calculate acf}
\item{auto.layout}{If \code{TRUE} then, set up own layout for
plots, otherwise use existing one.}
\item{ask}{If \code{TRUE} then prompt user before displaying
  each page of plots.}
\item{...}{graphical parameters}
}

\description{
Plots the autocorrelation function for each variable in each chain in x.
}

\seealso{
   \code{\link{autocorr}}.
}
\keyword{hplot}

\eof
\name{bugs2jags}
\alias{bugs2jags}
\title{Convert WinBUGS data file to JAGS data file}
\usage{
bugs2jags(infile, outfile)
}
\arguments{
  \item{infile}{name of the input file}
  \item{outfile}{name of the output file}
}
\description{
  \code{bugs2jags} converts a WinBUGS data in the format called "S-Plus"
  (i.e. the format created by the \code{dput} function) and writes it in
  \code{dump} format used by JAGS.
  
  NB WinBUGS stores its arrays in row order.  This is different
  from R and JAGS which both store arrays in column order. This
  difference is taken into account by \code{bugs2jags} which will
  automatically reorder the data in arrays, without changing the
  dimension.
}
\references{
  Spiegelhalter DJ, Thomas A, Best NG and Lunn D (2003).
  \emph{WinBUGS version 1.4 user manual}
  MRC Biostatistics Unit, Cambridge, UK.
}
\author{Martyn Plummer}
\seealso{
   \code{\link{dput}}, 
   \code{\link{dump}}.
}
\keyword{file}


\eof
\name{change.tfoption}
\alias{change.tfoption}
\title{Interactively modify logical codamenu options.}

\usage{
change.tfoption(string, option)
}

\arguments{
\item{string}{Prompt string to print}
\item{option}{String giving the name of an option to change}
}

\description{
Interactively changes logical codamenu options using the 
\code{read.yesno} function.
}

\note{
This is a utility function for the codamenu system, and is not
meant to be called directly by the user.
}

\seealso{
   \code{\link{coda.options}}, 
   \code{\link{read.yesno}}.
}

\keyword{utilities}

\eof
\name{coda.global.assign}
\alias{coda.global.assign}
\title{Cross-platform assignment to global environment}

\usage{
coda.global.assign(name, value, alias = FALSE) 
}

\arguments{
  \item{name}{A variable name (given as a quoted string)}
  \item{value}{Value to be assigned to \code{x}}
  \item{alias}{Logical value that determines whether a copy is made or an alias is assigned}
}

\description{
  An attempt to overcome syntactic differences between R and S when assigning
  to the global environment, but not a very good one.
}

\keyword{data}

\eof
\name{coda.options}
\alias{coda.options}
\alias{display.coda.options}
\alias{.Coda.Options}
\alias{.Coda.Options.Default}
\title{Options settings for the codamenu driver}

\usage{
coda.options(...)
display.coda.options(data = FALSE, stats = FALSE, plots = FALSE, diags = FALSE)
.Coda.Options
.Coda.Options.Default
}

\arguments{
  \item{data}{logical flag: show data options?}
  \item{stats}{logical flag: show summary statistic options?}
  \item{plots}{logical flag: show plotting options?}
  \item{diags}{logical flag: show plotting options?}
  \item{...}{list of options}
}

\description{
  \code{coda.options} is a utility function that queries and sets
  options for the \code{codamenu()} function.  These settings affect
  the behaviour of the functions in the coda library only when they
  are called via the \code{codamenu()} interface.
  
  The \code{coda.options()} function behaves just like the
  \code{options()} function in the base library, with the additional
  feature that \code{coda.options(default=TRUE)} will reset all options
  to the default values.
  
  Options can be pretty-printed using the \code{display.coda.options()}
  function, which groups the options into sections.
  
  Available options are
  \describe{
    \item{bandwidth}{Bandwidth function used when smoothing samples to
      produce density estimates.  Defaults to Silverman's ``Rule of thumb''.}
    \item{combine.corr}{Logical option that determines whether to
      combine multiple chains when calculating cross-correlations.}
    \item{combine.plots}{Logical option that determines whether to
      combine multiple chains when plotting.}
    \item{combine.plots}{Logical option that determines whether to
      combine multiple chains when calculating summary statistics.}
    \item{data.saved}{For internal use only.}
    \item{densplot}{Logical option that determines whether to plot
      a density plot when plot methods are called for mcmc objects.}
    \item{digits}{Number of significant digits to use when printing.}
    \item{frac1}{For Geweke diagnostic, fraction to use from
      start of chain.  Defaults to 0.1}
    \item{frac2}{For Geweke diagnostic, fraction to use from
      end of chain.  Default to 0.5.}
    \item{gr.bin}{For Geweke-Brooks plot, number of iterations to use
      per bin.}
    \item{gr.max}{For Geweke-Brooks plot, maximum number of bins to
      use.  This option overrides \code{gr.bin}.}
    \item{halfwidth}{For Heidelberger and Welch diagnostic, the target
      value for the ratio of half width to sample mean.}
    \item{lowess}{Logical option that controls whether to plot a 
      smooth line through a trace plot when plotting MCMC output.}
    \item{q}{For Raftery and Lewis diagnostic, the target quantile to
      be estimated}
    \item{r}{For Raftery and Lewis diagnostic, the required precision.}
    \item{s}{For Raftery and Lewis diagnostic, the probability of
      obtaining an estimate in the interval (q-r, q+r).}
    \item{quantiles}{Vector of quantiles to print when calculating
      summary statistics for MCMC output.}
    \item{trace}{Logical option that determines whether to plot a trace
      of the sampled output when plotting MCMC output.}
    \item{user.layout}{Logical option that determines whether current
      value of par("mfrow") should be used for plots (TRUE) or whether
      the optimal layout should be calculated (FALSE).}
  }
}

\seealso
{
  \link{\code{options}}.
}
\keyword{utilities}

\eof
\name{codamenu}
\alias{codamenu}
\title{Main menu driver for the coda package}

\usage{
codamenu()
}

\description{
\code{codamenu} presents a simple menu-based interface to the functions
in the coda package.  It is designed for users who know nothing about
the R language.}

\author{Kate Cowles, Nicky Best, Karen Vines, Martyn Plummer}
\keyword{utilities}

\eof
\name{codamenu2}
\alias{codamenu.main}
\alias{codamenu.anal}
\alias{codamenu.diags}
\alias{codamenu.diags.autocorr}
\alias{codamenu.diags.crosscorr}
\alias{codamenu.diags.heidel}
\alias{codamenu.diags.raftery}
\alias{codamenu.diags.gelman}
\alias{codamenu.diags.geweke}
\alias{codamenu.options}
\alias{codamenu.options.data}
\alias{codamenu.options.diag}
\alias{codamenu.options.gelman}
\alias{codamenu.options.geweke.bin}
\alias{codamenu.options.geweke.win}
\alias{codamenu.options.heidel}
\alias{codamenu.options.plot}
\alias{codamenu.options.plot.kernel}
\alias{codamenu.options.plot.ps}
\alias{codamenu.options.raftery}
\alias{codamenu.options.stats}
\alias{tidy.up}
\alias{codamenu.ps}
\alias{codamenu.output.header}

\title{Submenus for the coda package}

\description{
These functions are not meant to be called directly by the user, but
should be accessed via the \code{codamenu} function.

All submenus are called from the \code{codamenu.main} function.
Each submenu returns a string giving the name of the next submenu to be
called, or "quit" if the user decides to quit.  This system avoids the
recursive calling of submenus which would accumulate `dead' environments.
}

\author{Martyn Plummer}
\keyword{utilities}

\eof
\name{crosscorr}
\alias{crosscorr}
\title{Cross correlations for MCMC output}

\usage{crosscorr(x)}

\arguments{
   \item{x}{an \code{mcmc} or \code{mcmc.list} object.}
}
\description{
   \code{crosscorr} calculates cross-correlations between
   variables in Markov Chain Monte Carlo output. If \code{x}
   is an mcmc.list then all chains in \code{x} are combined
   before calculating the correlation.
}

\value{
A matrix or 3-d array containing the correlations.
}

\seealso{
   \code{\link{crosscorr.plot}}, \code{\link{autocorr}}.
}
\keyword{multivariate}
\keyword{array}

\eof
\name{crosscorr.plot}
\alias{crosscorr.plot}
\title{Plot image of correlation matrix}

\usage{crosscorr.plot (x, col = topo.colors(10), ...)}

\arguments{
\item{x}{an \code{mcmc} or \code{mcmc.list} object}
\item{col}{color palette to use}
\item{...}{graphical parameters}
}

\description{
\code{crosscorr.plot} provides an image of the correlation matrix for
\code{x}. If \code{x} is an \code{mcmc.list} object, then all chains
are combined.

The range [-1,1] is divided into a number of equal-length categories
given by the length of \code{col} and assigned the corresponding color.
By default, topographic colours are used as this makes it easier to
distinguish positive and negative correlations.
}

\seealso{
\code{\link{crosscorr}}, \code{\link{image}}, \code{\link{topo.colors}}.
}
\keyword{hplot}

\eof
\name{cumuplot}
\alias{cumuplot}
\title{Cumulative quantile plot}

\usage{
  cumuplot(x, probs=c(0.025,0.5,0.975), ylab="",
           lty=c(2,1), lwd=c(1,2), type="l", ask=TRUE, auto.layout=TRUE, 
	   col=1, ...)
}

\arguments{
  \item{x}{an \code{mcmc} object}
  \item{probs}{vector of desired quantiles}
  \item{ylab, lty, lwd, type, col}{graphical parameters}
  \item{auto.layout}{If \code{TRUE}, then set up own layout for
   plots, otherwise use existing one.}
  \item{ask}{If \code{TRUE} then prompt user before displaying
   each page of plots.}
  \item{...}{further graphical parameters}
}

\description{
  Plots the evolution of the sample quantiles as a function of the
  number of iterations.
}
  
\author{
  Arni Magnusson <arnima@u.washington.edu>
}
\keyword{hplot}

\eof
\name{densplot}
\alias{densplot}
\title{Probability density function estimate from MCMC output}

\usage{densplot(x, show.obs=TRUE, bwf, main, ylim, ...)}

\arguments{
  \item{x}{An \code{mcmc} or \code{mcmc.list} object}
  \item{show.obs}{Show observations along the x-axis}
  \item{bwf}{Function for calculating the bandwidth.  If omitted,
    the bandwidth is calculate by 1.06 times the minimum of the standard
    deviation and the interquartile range divided by 1.34 times the sample
    size to the negative one fifth power}
  \item{main}{Title. See \code{par()}}
  \item{ylim}{Limits on y axis.  See \code{par()}}
  \item{...}{Further graphical parameters}
}

\description{
  Displays a plot of the density estimate for each variable in \code{x},
  calculated by the \code{density} function.
}

\note{
  You can call this function directly, but it is more usually
  called by the \code{plot.mcmc} function.

  If a variable is bounded below at 0, or bounded in the interval [0,1],
  then the data are reflected at the boundary before being passed to the
  density() function. This allows correct estimation of a non-zero
  density at the boundary.
}

\seealso{
  \code{\link{density}}, \code{\link{plot.mcmc}}.
}
\keyword{hplot}

\eof
\name{effectiveSize}
\alias{effectiveSize}
\title{Effective sample size for estimating the mean}
\description{
Sample size adjusted for autocorrelation.
}
\usage{
effectiveSize(x) 
}
\arguments{
\item{x}{An mcmc or mcmc.list object.}
}
\details{
For a time series \code{x} of length \code{N}, the standard error of
the mean is \code{var(x)/n} where \code{n} is the effective sample
size.  \code{n = N} only when there is no autocorrelation.

Estimation of the effective sample size requires estimating the
spectral density at frequency zero.  This is done by the function
\code{spectrum0.ar}
}
\value{
A vector giving the effective sample size for each column of \code{x}.
}
\seealso{
   \code{\link{spectrum0.ar}}.
}
\keyword{ts}

\eof
\name{gelman.diag}
\alias{gelman.diag}
\alias{gelman.mv.diag}
\alias{gelman.transform}
\alias{print.gelman.diag}
\title{Gelman and Rubin's convergence diagnostic}

\usage{gelman.diag(x, confidence = 0.95, transform=FALSE)}

\arguments{
\item{x}{An \code{mcmc.list} object with more than one chain,
and with starting values that are overdispersed with respect to the
posterior distribution.}
\item{confidence}{the coverage probability of the confidence interval for the
potential scale reduction factor}
\item{transform}{a logical flag indicating whether variables in
\code{x} should be transformed to improve the normality of the
distribution. If set to TRUE, a log transform or logit transform, as
appropriate, will be applied.}
}

\description{
The `potential scale reduction factor' is calculated for each variable in
\code{x}, together with upper and lower confidence limits. Approximate
convergence is diagnosed when the upper limit is close to 1. For
multivariate chains, a multivariate value is calculated that bounds
above the potential scale reduction factor for any linear combination
of the (possibly transformed) variables.

The confidence limits are based on the assumption that the stationary
distribution of the variable under examination is normal. Hence the
`transform' parameter may be used to improve the normal approximation.
}

\section{Theory}{
Gelman and Rubin (1992) propose a general approach to monitoring
convergence of MCMC output in which two or more parallel chains are run
with starting values that are overdispersed relative to the posterior
distribution. Convergence is diagnosed when the chains have `forgotten'
their initial values, and the output from all chains is indistinguishable.
The \code{gelman.diag} diagnostic is applied to a single variable from
the chain. It is based a comparison of within-chain and between-chain
variances, and is similar to a classical analysis of variance.

There are two ways to estimate the variance of the stationary distribution:
the mean of the empirical variance within each chain, \eqn{W}, and
the empirical variance from all chains combined, which can be expressed as
\deqn{ \widehat{\sigma}^2 = 
   \frac{(n-1) B }{n} + \frac{W}{n} }{ sigma.hat^2 =  (n-1)B/n + W/n }
where \eqn{B} is the empirical between-chain variance.

If the chains have converged, then both estimates are unbiased. Otherwise
the first method will \emph{underestimate} the variance, since the
individual chains have not had time to range all over the stationary
distribution, and the second method will \emph{overestimate} the variance,
since the starting points were chosen to be overdispersed. 

The convergence diagnostic is based on the assumption that the
target distribution is normal. A Bayesian credible interval can
be constructed using a t-distribution with mean
\deqn{\widehat{\mu}=\mbox{Sample mean of all chains
combined}}{mu.hat = Sample mean of all chains combined}
and variance
\deqn{\widehat{V}=\widehat{\sigma}^2 + \frac{B}{mn}}{V.hat=sigma.hat2 + B/(mn)}
where \eqn{m} is the number of chains, and degrees of freedom
estimated by the method of moments
\deqn{d = \frac{2*\widehat{V}}{\mbox{Var}(\widehat{V})}}{d = 2*V.hat/Var(V.hat)}
Use of the t-distribution accounts for the fact that the mean
and variance of the posterior distribution are estimated.

The convergence diagnostic itself is
\deqn{R=\sqrt{\frac{(d+3) \widehat{V}}{(d+1)W}}}{R=sqrt((d+3) V.hat /((d+1)W)}
Values substantially above 1 indicate lack of convergence.  If the
chains have not converged, Bayesian credible intervals based on the
t-distribution are too wide, and have the potential to shrink by this
factor if the MCMC run is continued.
}

\note{
The multivariate a version of Gelman and Rubin's diagnostic was
proposed by Brooks and Gelman (1997).
}

\references{
Gelman, A and Rubin, DB (1992) Inference from iterative simulation
using multiple sequences, \emph{Statistical Science}, \bold{7}, 457-511.

Brooks, SP. and Gelman, A. (1997) General methods for monitoring
convergence of iterative simulations. \emph{Journal of Computational and
Graphical Statistics}, \bold{7}, 434-455.
}

\seealso{
   \code{\link{gelman.plot}}.
}
\keyword{htest}

\eof
\name{gelman.plot}
\alias{gelman.plot}
\alias{gelman.preplot}
\title{Gelman-Rubin-Brooks plot}

\usage{
gelman.plot(x, bin.width = 10, max.bins = 50,
confidence = 0.95, transform = FALSE, auto.layout = TRUE, ask = TRUE,
col, lty, xlab, ylab, type, ...)
} 

\arguments{
  \item{x}{an mcmc object}
  \item{bin.width}{Number of observations per segment, excluding the
    first segment which always has at least 50 iterations.}
  \item{max.bins}{Maximum number of bins, excluding the last one.}
  \item{confidence}{Coverage probability of confidence interval.}
  \item{transform}{Automatic variable transformation (see \code{gelman.diag})}
  \item{auto.layout}{If \code{TRUE} then, set up own layout for
    plots, otherwise use existing one.}
  \item{ask}{Prompt user before displaying each page of plots.}
  \item{col}{graphical parameter (see \code{par})}
  \item{lty}{graphical parameter (see \code{par})}
  \item{xlab}{graphical parameter (see \code{par})}
  \item{ylab}{graphical parameter (see \code{par})}
  \item{type}{graphical parameter (see \code{par})}
  \item{...}{further graphical parameters.}
}

\description{
This plot shows the evolution of Gelman and Rubin's shrink factor as
the number of iterations increases. 
}

\details{
The Markov chain is divided into bins according to the arguments
\code{bin.width} and \code{max.bins}. Then the Gelman-Rubin shrink factor
is repeatedly calculated. The first shrink factor is calculated with
observations 1:50, the second with observations \eqn{1:(50+n)} where n is
the bin width, the third contains samples \eqn{1:(50+2n)} and so on.
}

\references{
Brooks, S P. and Gelman, A. (1998) General Methods for Monitoring
Convergence of Iterative Simulations. Journal of Computational and
Graphical Statistics. 7. p434-455.
}

\section{Theory}{
A potential problem with \code{gelman.diag} is that it may mis-diagnose
convergence if the shrink factor happens to be close to 1 by chance.
By calculating the shrink factor at several points in time,
\code{gelman.plot} shows if the shrink factor has really converged, or
whether it is still fluctuating.
}

\seealso{
   \code{\link{gelman.diag}}.
}
\keyword{hplot}

\eof
\name{geweke.diag}
\alias{geweke.diag}
\alias{print.geweke.diag}
\title{Geweke's convergence diagnostic}

\usage{geweke.diag(x, frac1=0.1, frac2=0.5)}

\arguments{
  \item{x}{an mcmc object}
  \item{frac1}{fraction to use from beginning of chain}
  \item{frac2}{fraction to use from end of chain}
}

\value{
Z-scores for a test of equality of means
between the first and last parts of the chain. A separate
statistic is calculated for each variable in each chain.
}

\description{
Geweke (1992) proposed a convergence diagnostic for Markov chains
based on a test for equality of the means of the first and last part
of a Markov chain (by default the first 10\% and the last 50\%).  If the
samples are drawn from the stationary distribution of the chain, the two
means are equal and Geweke's statistic has an asymptotically standard
normal distribution.

The test statistic is a standard Z-score: the difference between the
two sample means divided by its estimated standard error.  The standard
error is estimated from the spectral density at zero and so takes into
account any autocorrelation.

The Z-score is calculated under the assumption that the two parts of
the chain are asymptotically independent, which requires that the sum
of \code{frac1} and \code{frac2} be strictly less than 1.
}

\seealso{
   \code{\link{geweke.plot}}.
}

\references{
Geweke, J. Evaluating the accuracy of sampling-based approaches
to calculating posterior moments. In \emph{Bayesian Statistics 4}
(ed JM Bernado, JO Berger, AP Dawid and AFM Smith). Clarendon Press,
Oxford, UK.}

\keyword{htest}

\eof
\name{geweke.plot}
\alias{geweke.plot}
\title{Geweke-Brooks plot}

\usage{
geweke.plot(x, frac1 = 0.1, frac2 = 0.5, nbins = 20,
            pvalue = 0.05, auto.layout = TRUE, ask = TRUE, ...)
} 

\arguments{
  \item{x}{an mcmc object}
  \item{frac1}{fraction to use from beginning of chain.}
  \item{frac2}{fraction to use from end of chain.}
  \item{nbins}{Number of segments.}
  \item{pvalue}{p-value used to plot confidence limits for the null hypothesis.}
  \item{auto.layout}{If \code{TRUE} then, set up own layout for
    plots, otherwise use existing one.}
  \item{ask}{Prompt user before displaying each page of plots.}
  \item{...}{Graphical parameters.}
}

\description{
If \code{geweke.diag} indicates that the first and last part of a sample
from a Markov chain are not drawn from the same distribution, it may
be useful to discard the first few iterations to see if the rest of the
chain has "converged". This plot shows what happens to Geweke's Z-score
when successively larger numbers of iterations are discarded from the
beginning of the chain. To preserve the asymptotic conditions required
for Geweke's diagnostic, the plot never discards more than half the chain.

The first half of the Markov chain is divided into \code{nbins - 1}
segments, then Geweke's Z-score is repeatedly calculated. The first
Z-score is calculated with all iterations in the chain, the second
after discarding the first segment, the third after discarding the first
two segments, and so on. The last Z-score is calculated using only the
samples in the second half of the chain.
}

\note{
The graphical implementation of Geweke's diagnostic was suggested
by Steve Brooks.
}

\seealso{
   \code{\link{geweke.diag}}.
}
\keyword{hplot}

\eof
\name{heidel.diag}
\alias{heidel.diag}
\alias{print.heidel.diag}
\title{Heidelberger and Welch's convergence diagnostic}

\usage{heidel.diag(x, eps=0.1, pvalue=0.05)}

\arguments{
\item{x} {An \code{mcmc} object}
\item{eps}{Target value for ratio of halfwidth to sample mean}
\item{pvalue}{significance level to use}
}

\description{
\code{heidel.diag} is a run length control diagnostic based on a criterion
of relative accuracy for the estimate of the mean.  The default setting
corresponds to a relative accuracy of two significant digits.

\code{heidel.diag} also implements a convergence diagnostic, and removes
up to half the chain in order to ensure that the means are estimated
from a chain that has converged.
}

\details{
The convergence test uses the Cramer-von-Mises statistic to test the null
hypothesis that the sampled values come from a stationary distribution.
The test is successively applied, firstly  to the whole chain, then after
discarding the first 10\%, 20\%, ... of the chain until either the null
hypothesis is accepted, or 50\% of the chain has been discarded. The latter
outcome constitutes `failure' of the stationarity test and indicates
that a longer MCMC run is needed. If the stationarity test is passed,
the number of iterations to keep and the number to discard are reported.

The half-width test calculates a 95\% confidence interval for the
mean, using the portion of the chain which passed the stationarity test.
Half the width of this interval is compared with the estimate of the mean.
If the ratio between the half-width and the mean is lower than \code{eps},
the halfwidth test is passed. Otherwise the length of the sample is
deemed not long enough to estimate the mean with sufficient accuracy.
}

\section{Theory}{
The \code{heidel.diag} diagnostic is based on the work of Heidelberger
and Welch (1983), who combined their earlier work on simulation run
length control (Heidelberger and Welch, 1981) with the work of Schruben
(1982) on detecting initial transients using Brownian bridge theory.
}

\note{
If the half-width test fails then the run should be extended.  In order
to avoid problems caused by sequential testing, the test should not
be repeated too frequently.  Heidelberger and Welch (1981) suggest
increasing the run length by a factor I > 1.5, each time, so that 
estimate has the same, reasonably large, proportion of new data.
}

\references{
Heidelberger P and Welch PD. A spectral method for confidence interval
generation and run length control in simulations. Comm. ACM. \bold{24},
233-245 (1981)

Heidelberger P and Welch PD. Simulation run length control in the 
presence of an initial transient. \emph{Opns Res.}, \bold{31},
1109-44 (1983)

Schruben LW. Detecting initialization bias in simulation experiments.
\emph{Opns. Res.}, \bold{30}, 569-590 (1982).
}

\keyword{htest}

\eof
\name{line}
\docType(data)
\alias{line}
\title{Simple linear regression example}
\description{
  Sample MCMC output from a simple linear regression model given in
  the BUGS manual.
}
\usage{data(line)}
\format{An \code{mcmc} object}
\source{
Spiegelhalter, D.J., Thomas, A., Best, N.G. and Gilks, W.R. (1995)
BUGS: Bayesian inference using Gibbs Sampling, Version 0.5, 
MRC Biostatistics Unit, Cambridge.
}
\keyword{datasets}

\eof
\name{mcmc}
\alias{mcmc}
\alias{as.mcmc}
\alias{as.mcmc.default}
\alias{is.mcmc}
\alias{print.mcmc}
\title{Markov Chain Monte Carlo Objects}

\usage{
mcmc(data= NA, start = 1, end = numeric(0), thin = 1)
as.mcmc(x)
is.mcmc(x)
}

\arguments{
  \item{data}{a vector or  matrix of MCMC output}
  \item{start}{the iteration number of the first observation}
  \item{end}{the iteration number of the last observation}
  \item{thin}{the thinning interval between consecutive observations}
  \item{x}{An object that may be coerced to an mcmc object}
}

\description{

   The function `mcmc' is used to create a Markov Chain Monte Carlo object.
   The data are taken to be a vector, or a matrix with one column per
   variable.

   An mcmc object may be summarized by the \code{summary} function
   and visualized with the \code{plot} function.

   MCMC objects resemble time series (\code{ts}) objects and have
   methods for the generic functions \code{time}, \code{start},
   \code{end}, \code{frequency} and \code{window}.
}

\author{Martyn Plummer}

\note{
   The format of the mcmc class has changed between coda version 0.3
   and 0.4.  Older mcmc objects will now cause \code{is.mcmc} to
   fail with an appropriate warning message.  Obsolete mcmc objects can
   be upgraded with the \code{mcmcUpgrade} function.
}


\seealso{
   \code{\link{mcmc.list}},
   \code{\link{mcmcUpgrade}},
   \code{\link{thin}},
   \code{\link{window.mcmc}},
   \code{\link{summary.mcmc}},
   \code{\link{plot.mcmc}}.
}

\keyword{ts}

\eof
\name{mcmc.convert}
\alias{as.matrix.mcmc}
\alias{as.matrix.mcmc.list}
\alias{as.array.mcmc.list}
\alias{as.mcmc.mcmc.list}
\title{Conversions of MCMC objects}

\usage{
as.matrix.mcmc(x, iters = FALSE)
as.matrix.mcmc.list(x, iters = FALSE, chains = FALSE)
as.array.mcmc.list(x, drop, ...)
}

\arguments{
  \item{x}{An \code{mcmc} or \code{mcmc.list} object}
  \item{iters}{logical flag: add column for iteration number?}
  \item{chains}{logical flag: add column for chain number?}
  \item{drop}{logical flag: if \code{TRUE} the result is coerced to the
    lowest possible dimension}
  \item{...}{further arguments for future methods}
}

\description{
	These are methods for the generic functions \code{as.matrix()},
	\code{as.array()} and \code{as.mcmc()}.

	\code{as.matrix()} strips the MCMC attributes from an \code{mcmc}
	object and returns a matrix.  If \code{iters = TRUE} then a
	column is added with the iteration number.  For \code{mcmc.list}
	objects, the rows of multiple chains are concatenated and, if
	\code{chains = TRUE} a column is added with the chain number.

	\code{mcmc.list} objects can be coerced to 3-dimensional arrays
	with the \code{as.array()} function.

	An \code{mcmc.list} object with a single chain can be coerced
	to an \code{mcmc} object with \code{as.mcmc()}.  If the argument
	has multiple chains, this causes an error.
}

\seealso{
   \code{\link{as.matrix}},
   \code{\link{as.array}},
   \code{\link{as.mcmc}},
}

\keyword{array}

\eof
\name{mcmc.list}
\alias{mcmc.list}
\alias{as.mcmc.list}
\alias{as.mcmc.list.default}
\alias{is.mcmc.list}
\alias{plot.mcmc.list}
\title{Replicated Markov Chain Monte Carlo Objects}

\usage{
mcmc.list(...)
as.mcmc.list(x, ...)
is.mcmc.list(x)
}

\arguments{
  \item{...}{a list of mcmc objects}
  \item{x}{an object that may be coerced to mcmc.list}
}


\description{

The function `mcmc.list' is used to represent parallel runs of the same
chain, with different starting values and random seeds.  The list must
be balanced: each chain in the list must have the same iterations and
the same variables.

Diagnostic functions which act on \code{mcmc} objects may also be applied
to \code{mcmc.list} objects. In general, the chains will be combined,
if this makes sense, otherwise the diagnostic function will be applied
separately to each chain in the list.

Since all the chains in the list have the same iterations, a single time
dimension can be ascribed to the list. Hence there are time series methods
\code{time}, \code{window}, \code{start}, \code{end}, \code{frequency}
and \code{thin} for \code{mcmc.list} objects.

An \code{mcmc.list} can be indexed as if it were a single mcmc object
using the \code{[} operator (see examples below). The \code{[[} operator
selects a single \code{mcmc} object from the list.
}

\author{Martyn Plummer}

\seealso{
   \code{\link{mcmc}}.
}

\examples{
data(line)
x1 <- line[[1]]			#Select first chain
x2 <- line[,1, drop=FALSE]	#Select first var from all chains
varnames(x2) == varnames(line)[1]	#TRUE
}

\keyword{ts}

\eof
\name{mcmc.subset}
\alias{[.mcmc}
\alias{[.mcmc.list}
\title{Extract or replace parts of MCMC objects}

\usage{
x[i,j]
}

\arguments{
   \item{x}{An \code{mcmc} object}
   \item{i}{Row to extract}
   \item{j}{Column to extract}
}

\description{

   These are methods for subsetting \code{mcmc} objects.  You can select
   iterations using the first dimension and variables using the second
   dimension.  Selecting iterations will return a vector or matrix, not an
   \code{mcmc} object. If you want to do row-subsetting of an \code{mcmc}
   object and preserve its dimensions, use the \code{window} function.

   Subsetting applied to an \code{mcmc.list} object will simultaneously 
   affect all the parallel chains in the object.
}

\seealso{
   \code{\link{[}},
   \code{\link{window.mcmc}}
}

\keyword{ts}

\eof
\name{mcmcUpgrade}
\alias{mcmcUpgrade}
\title{Upgrade mcmc objects in obsolete format}

\usage{
   mcmcUpgrade(x)
}

\arguments{
   \item{x}{an obsolete \code{mcmc} object.}
}

\description{
   In previous releases of CODA, an \code{mcmc}  object could
   be a single or multiple chains.  A new class \code{mcmc.list}
   has now been introduced to deal with multiple chains and
   \code{mcmc} objects can only have data from a single chain.

   Objects stored in the old format are now obsolete
   and must be upgraded.
}

\author{Martyn Plummer}

\seealso{
   \code{\link{mcmc}}.
}

\keyword{ts}

\eof
\name{mcpar}
\alias{mcpar}
\title{Mcpar attribute of MCMC objects}

\usage{
mcpar(x)
}

\arguments{
\item{x}{An \code{mcmcm} or \code{mcmc.list} object}
}

\description{
     The `mcpar' attribute of an MCMC object gives the start iteration
     the end iteration and the thinning interval of the chain.

     It resembles the `tsp' attribute of time series (\code{ts}) objects.
}

\seealso{
   \code{\link{ts}},
   \code{\link{mcmc}},
   \code{\link{mcmc.list}},
}

\keyword{ts}

\eof
\name{multi.menu}
\alias{multi.menu}
\title{Choose multiple options from a menu}

\usage{
multi.menu(choices, title, header, allow.zero = TRUE)
}

\arguments{
  \item{choices}{Character vector of labels for choices}
  \item{title}{Title printed before menu}
  \item{header}{Character vector of length 2 giving column titles}
  \item{allow.zero}{Permit 0 as an acceptable response}
}

\description{
\code{multi.menu} presents the user with a menu of choices
labelled from 1 to the number of choices.  The user may choose
one or more options by entering a comma separated list. A range
of values may also be specified using the ":" operator. Mixed
expressions such as "1,3:5, 6" are permitted.

If \code{allow.zero} is set to TRUE, one can select `0' to exit
without choosing an item.
}

\value{
Numeric vector giving the numbers of the options selected, or
0 if no selection is made.
}

\author{Martyn Plummer}

\seealso{
   \code{\link{menu}}.
}
\keyword{utilities}

\eof
\name{nchain}
\alias{niter}
\alias{nvar}
\alias{nchain}
\title{Dimensions of MCMC objects}

\usage{
niter(x)
nvar(x)
nchain(x)
}

\arguments{
  \item{x}{An \code{mcmc} or \code{mcmc.list} object}
}

\value{
  A numeric vector of length 1:
}

\description{
  These functions give the dimensions of an MCMC object

  \describe{
    \item{niter(x)}{returns the number of iterations.}
    \item{nvar(x)}{returns the number of variables.}
    \item{chain(x)}{returns the number of parallel chains.}
  }
}

\seealso{
  \code{\link{mcmc}},
  \code{\link{mcmc.list}},
}

\keyword{ts}

\eof
\name{plot.mcmc}
\alias{plot.mcmc}
\title{Summary plots of mcmc objects}

\usage{
\method{plot}{mcmc}(x, trace = TRUE, density = TRUE, smooth = TRUE, bwf,
	auto.layout = TRUE, ask = TRUE, ...)
}

\arguments{
  \item{x}{an object of class \code{mcmc} or \code{mcmc.list}}
  \item{trace}{Plot trace of each variable}
  \item{density}{Plot density estimate of each variable}
  \item{smooth}{Draw a smooth line through trace plots}
  \item{bwf}{Bandwidth function for density plots}
  \item{auto.layout}{Automatically generate output format}
  \item{ask}{Prompt user before each page of plots}
  \item{...}{Further arguments}
}

\description{
   \code{plot.mcmc} summarizes an mcmc or mcmc.list object
   with a trace of the sampled output and a density estimate
   for each variable in the chain.
}

\author{Martyn Plummer}

\seealso{
   \code{\link{densplot}}, \code{\link{traceplot}}.
}
\keyword{hplot}

\eof
\name{raftery.diag}
\alias{raftery.diag}
\alias{print.raftery.diag}
\title{Raftery and Lewis's diagnostic}

\usage{
raftery.diag(data, q=0.025, r=0.005, s=0.95, converge.eps=0.001)
}

\arguments{
   \item{data}{an \code{mcmc} object}
   \item{q}{the quantile to be estimated.}
   \item{r}{the desired margin of error of the estimate.}
   \item{s}{the probability of obtaining an estimate in the interval (q-r,q+r).}
   \item{converge.eps}{Precision required for estimate of time to convergence.}
}

\description{
   \code{raftery.diag} is a run length control diagnostic based on a
   criterion of accuracy of estimation of the quantile \code{q}.  It is
   intended for use on a short pilot run of a Markov chain.  The number
   of iterations required to estimate the quantile \eqn{q} to within an
   accuracy of +/- \eqn{r} with probability \eqn{p} is calculated. Separate
   calculations are performed for each variable within each chain.

   If the number of iterations in \code{data} is too small,
   an error message is printed indicating the minimum length of
   pilot run.  The minimum length is the required sample size for a
   chain with no correlation between consecutive samples. Positive
   autocorrelation will increase the required sample size above this
   minimum value. An estimate \code{I} (the `dependence factor') of the
   extent to which autocorrelation inflates the required sample size
   is also provided. Values of \code{I} larger than 5 indicate strong
   autocorrelation which may be due to a poor choice of starting value,
   high posterior correlations or `stickiness' of the MCMC algorithm.

   The number of `burn in' iterations to be discarded at the beginning
   of the chain is also calculated.
}

\value{
   A list with class \code{raftery.diag}.  A print method is available
   for objects of this class. the contents of the list are
      \item{tspar}{The time series parameters of \code{data}}
      \item{params}{A vector containing the parameters \code{r}, \code{s}
      and \code{q}}
      \item{Niters}{The number of iterations in \code{data}}
      \item{resmatrix}{A 3-d array containing the results: \eqn{M} the
      length of "burn in", \eqn{N} the required sample size, \eqn{Nmin}
      the minimum sample size based on zero autocorrelation and 
      \eqn{I = (M+N)/Nmin} the "dependence factor"}
}

\section{Theory}{
   The estimated sample size for variable U is based on the process \eqn{Z_t
   = d(U_t <= u)} where \eqn{d} is the indicator function and u is the
   qth quantile of U. The process \eqn{Z_t} is derived from the Markov
   chain \code{data} by marginalization and truncation, but is not itself
   a Markov chain.  However, \eqn{Z_t} may behave as a Markov chain if
   it is sufficiently thinned out.  \code{raftery.diag} calculates the
   smallest value of thinning interval \eqn{k} which makes the thinned
   chain \eqn{Z^k_t} behave as a Markov chain. The required sample size is
   calculated from this thinned sequence.  Since some data is `thrown away'
   the sample size estimates are conservative.

   The criterion for the number of `burn in' iterations \eqn{m} to be
   discarded, is that the conditional distribution of \eqn{Z^k_m}
   given \eqn{Z_0} should be within \code{converge.eps} of the equilibrium
   distribution of the chain \eqn{Z^k_t}.
}

\note{
   \code{raftery.diag} is based on the FORTRAN program `gibbsit' 
   written by Steven Lewis, and available from the Statlib archive.
}

\references{
   Raftery, A.E. and Lewis, S.M. (1992).  One long run with diagnostics:
   Implementation strategies for Markov chain Monte Carlo.
   \emph{Statistical Science}, \bold{7}, 493-497.

   Raftery, A.E. and Lewis, S.M. (1995).  The number of iterations,
   convergence diagnostics and generic Metropolis algorithms.  \emph{In}
   Practical Markov Chain Monte Carlo (W.R. Gilks, D.J. Spiegelhalter
   and S. Richardson, eds.). London, U.K.: Chapman and Hall.
}

\keyword{htest}

\eof
\name{read.and.check}
\alias{read.and.check}
\title{Read data interactively and check that it satisfies conditions}

\usage{
read.and.check(message = "", what = numeric(), lower, upper, answer.in,
default)
}

\arguments{
   \item{message}{message displayed before prompting for user input.}
   \item{what}{the type of \code{what} gives the type of data to be read.}
   \item{lower}{lower limit of input, for numeric input only.}
   \item{upper}{upper limit of input, for numeric input only.}
   \item{answer.in}{the input must correspond to one of the elements of the
   vector \code{answer.in}, if supplied.}
   \item{default}{value assumed if user enters a blank line.}
}

\description{
   Input is read interactively and checked against conditions specified
   by the arguments \code{what}, \code{lower}, \code{upper} and
   \code{answer.in}. If the input does not satisfy all the conditions,
   an appropriate error message is produced and the user is prompted
   to provide input. This process is repeated until a valid input value
   is entered.
}

\value{
   The value of the valid input.  When the \code{default} argument is
   specified, a blank line is accepted as valid input and in this case
   \code{read.and.check} returns the value of \code{default}.
}

\note{
   Since the function does not return a value until it receives valid
   input, it extensively checks the conditions for consistency before
   prompting the user for input.  Inconsistent conditions will cause
   an error.
}

\author{Martyn Plummer}

\keyword{utilities}

\eof
\name{read.bugs.interactive}
\alias{read.bugs.interactive}
\title{Read BUGS output files interactively}

\usage{
read.bugs.interactive()
}

\description{
   \code{read.bugs.interactive} reads Markov Chain Monte Carlo output
   in the format produced by the classic BUGS program. No arguments are
   required. Instead, the user is prompted for the required information.
}

\value{
   An object of class \code{mcmc.list} containing a representation of 
   the data in one or more BUGS output files.
}

\references{
   Spiegelhalter DJ, Thomas A, Best NG and Gilks WR (1995).
   \emph{BUGS: Bayesian inference Using Gibbs Sampling, Version 0.50.}
   MRC Biostatistics Unit, Cambridge.
}

\note{
   This function is normally called by the \code{codamenu} function,
   but can also be used on a stand-alone basis.
}

\author{Nicky Best, Martyn Plummer}

\seealso{
   \code{\link{mcmc}}, 
   \code{\link{mcmc.list}}, 
   \code{\link{read.bugs}}, 
   \code{\link{codamenu}}. 
}
\keyword{file}

\eof
\name{read.coda}
\alias{read.coda}
\alias{read.bugs}
\alias{read.jags}
\title{Read BUGS output files}

\usage{
read.coda(file, start, end, thin, quiet=FALSE)
read.bugs(file = "bugs.out", start, end, thin, quiet=FALSE)
read.jags(file = "jags.out", start, end, thin, quiet=FALSE)
}

\arguments{
   \item{file}{the name of the file from which the data are to be
   read.  The extension ".out" may be omitted. The data must be
   in the format produced by the BUGS program, and there  must be
   a corresponding ".ind" file} 
   \item{start}{First iteration of chain}
   \item{end}{Last iteration of chain}
   \item{thin}{Thinning interval for chain}
   \item{quiet}{Logical flag. If true, a progress summary will be printed}
}

\description{
   \code{read.coda} reads Markov Chain Monte Carlo output in
   the CODA format produced by WinBUGS and JAGS. By default, all
   of the data in the file is read, but the arguments \code{start},
   \code{end} and \code{thin} may be used to read a subset of the
   data.  If the arguments given to \code{start}, \code{end} or
   \code{thin} are incompatible with the data, they are ignored.
}

\value{
   An object of class \code{mcmc} containing a representation of 
   the data in the file.
}

\references{
   Spiegelhalter DJ, Thomas A, Best NG and Gilks WR (1995).
   \emph{BUGS: Bayesian inference Using Gibbs Sampling, Version 0.50.}
   MRC Biostatistics Unit, Cambridge.
}

\author{Karen Vines, Martyn Plummer}

\seealso{
   \code{\link{mcmc}}, 
   \code{\link{read.bugs.interactive}}.
}
\keyword{file}

\eof
\name{read.yesno}
\alias{read.yesno}
\title{Read logical values from the command line}

\usage{
   read.yesno(string, default=TRUE)
}

\arguments{
   \item{string}{A string to prompt the user with}
   \item{default}{Logical value giving the default answer}
}

\value{
   A single logical value.
}

\description{
   This is a utility function for interactively reading a logical
   value from the command line.

   The prompt string is printed, along a hint about the default answer.
   Answers "yes", "YES", "no", "NO" or any partial match are accepted.
   If the user enters a blank line, the default value is returned.
}

\author{Martyn Plummer}

\keyword{utilities}

\eof
\name{set.mfrow}
\alias{set.mfrow}
\title{Set layout for graphical plots}

\usage{
   set.mfrow (Nchains = 1, Nparms = 1, nplots = 1, sepplot = FALSE) 
}

\arguments{
   \item{Nchains}{Number of chains to plot}
   \item{Nparms}{Number of variables in each chain}
   \item{nplots}{Number of plots to produce}
   \item{sepplot}{Logical value controlling whether separate plots are created for each chain}
}

\description{
   This utility function is used by plotting functions in the coda package
   to determine the default layout, unless overriden by the \code{user.layout}
   option.
}

\note{
   This is not meant to be called directly by the user.
}

\keyword{dplot}

\eof
\name{spectrum0}
\alias{spectrum0}
\title{Estimate spectral density at zero}
\description{
The spectral density at frequency zero is estimated by fitting a glm to
the low-frequency end of the periodogram.  \code{spectrum0(x)/length(x)}
estimates the variance of \code{mean(x)}.

}
\usage{
spectrum0(x, max.freq = 0.5, order = 1, max.length = NULL) 
}
\arguments{
\item{x}{A time series.}
\item{max.freq}{The glm is fitted on the frequency range (0, max.freq]}
\item{order}{Order of the polynomial to fit to the periodogram.}

\item{max.length}{The data \code{x} is aggregated if necessary by
taking batch means so that the length of the series is less than
\code{max.length}.  If this is set to \code{NULL} no aggregation occurs.}
}
\details{
The raw periodogram is calculated for the series \code{x} and a generalized
linear model with family \code{Gamma} and log link is fitted to
the periodogram.

The linear predictor is a polynomial in terms of the frequency.  The
degree of the polynomial is determined by the parameter \code{order}.
}
\value{
A list with the following values
\item{spec}{The predicted value of the spectral density at frequency zero.}
}
\references{
Heidelberger, P and Welch, P.D. A spectral method for confidence interval
generation and run length control in simulations. Communications of the
ACM, Vol 24, pp233-245, 1981.
}
\section{Theory}{
Heidelberger and Welch (1991) observed that the usual non-parametric
estimator of the spectral density, obtained by smoothing the periodogram,
is not appropriate for frequency zero.  They proposed an alternative
parametric method which consisted of fitting a linear model to the
log periodogram of the batched time series. Some technical problems 
with model fitting in their original proposal can be overcome by using
a generalized linear model.

Batching of the data, originally proposed in order to save space, has the
side effect of flattening the spectral density and making a polynomial
fit more reasonable.  Fitting a polynomial of degree zero is equivalent
to using the `batched means' method.
}
\note{
The definition of the spectral density used here differs from that used by
\code{spec.pgram}. We consider the frequency range to be between 0 and 0.5,
not between 0 and \code{frequency(x)/2}.

The model fitting may fail on chains with very high autocorrelation.
}
\seealso{
   \code{\link{spectrum}}, \code{\link{spectrum0.ar}}, \code{\link{glm}}.
}
\keyword{ts}

\eof
\name{spectrum0.ar}
\alias{spectrum0.ar}
\title{Estimate spectral density at zero}
\description{
The spectral density at frequency zero is estimated by fitting an
autoregressive model.  \code{spectrum0(x)/length(x)} estimates the
variance of \code{mean(x)}.
}
\usage{
spectrum0.ar(x) 
}
\arguments{
\item{x}{A time series.}
}
\details{
The \code{ar()} function to fit an autoregressive model to the time
series x. For multivariate time series, separate models are fitted for
each column. The value of the spectral density at zero is then given
by a well-known formula.
}
\value{
A list with the following values
\item{spec}{The predicted value of the spectral density at frequency zero.}
\item{order}{The order of the fitted model}
}
\note{
The definition of the spectral density used here differs from that used by
\code{spec.pgram}. We consider the frequency range to be between 0 and 0.5,
not between 0 and \code{frequency(x)/2}.
}
\seealso{
   \code{\link{spectrum}}, \code{\link{spectrum0}}, \code{\link{glm}}.
}
\keyword{ts}

\eof
\name{summary.mcmc}
\alias{summary.mcmc}
\alias{summary.mcmc.list}
\alias{print.summary.mcmc}
\alias{print.summary.mcmc.list}
\title{Summary statistics for  Markov Chain Monte Carlo chains}

\usage{
\method{summary}{mcmc}(object, quantiles = c(0.025, 0.25, 0.5, 0.75, 0.975), ...)
}

\arguments{
  \item{object}{an object of class \code{mcmc} or \code{mcmc.list}}
  \item{quantiles}{a vector of quantiles to evaluate for each variable}
  \item{...}{a list of further arguments}
}

\description{
   \code{summary.mcmc} produces two sets of summary statistics for
   each variable:
   
   Mean, standard deviation, naive standard error of the mean
   (ignoring autocorrelation of the chain) and time-series standard
   error based on an estimate of the spectral density at 0.

   Quantiles of the sample distribution using the \code{quantiles}
   argument.
}

\author{Martyn Plummer}

\seealso{
   \code{\link{mcmc}},
   \code{\link{mcmc.list}}.
}
\keyword{univar}

\eof
\name{thin}
\alias{thin}
\title{Thinning interval}

\usage{
thin(x, ...)
}

\arguments{
   \item{x}{a regular time series}
   \item{...}{a list of arguments}
 }

\description{
   \code{thin} returns the interval between successive
   values of a time series. \code{thin(x)} is equivalent
   to \code{1/frequency(x)}.

   This is a generic function. Methods have been implemented
   for \code{mcmc} objects.
}

\author{Martyn Plummer}

\seealso{
   \code{\link{time}}.
}
\keyword{ts}

\eof
\name{time.mcmc}
\alias{time.mcmc}
\alias{start.mcmc}
\alias{end.mcmc}
\alias{frequency.mcmc}
\alias{thin.mcmc}
\alias{time.mcmc.list}
\alias{start.mcmc.list}
\alias{end.mcmc.list}
\alias{thin.mcmc.list}
\title{Time attributes for mcmc objects}

\usage{
\method{time}{mcmc}(x, ...)
\method{start}{mcmc}(x, ...)
\method{end}{mcmc}(x, ...)
\method{thin}{mcmc}(x, ...)
}

\arguments{
  \item{x}{an \code{mcmc} or \code{mcmc.list} object}
  \item{...}{extra arguments for future methods}
}

\description{
   These are methods for mcmc objects for the generic time
   series functions.
}

\seealso{
   \code{\link{time}},
   \code{\link{start}},
   \code{\link{frequency}},
   \code{\link{thin}}.
}
\keyword{ts}

\eof
\name{traceplot}
\alias{traceplot}
\title{Trace plot of MCMC output}

\usage{traceplot(x, smooth = TRUE, col, type, ylab, ...)}

\arguments{
  \item{x}{An \code{mcmc} or \code{mcmc.list} object}
  \item{smooth}{draw smooth line through trace plot}
  \item{col}{graphical parameter (see \code{par})}
  \item{type}{graphical parameter (see \code{par})}
  \item{ylab}{graphical parameter (see \code{par})}
  \item{...}{further graphical parameters}
}

\description{
Displays a plot of iterations \emph{vs.} sampled values for each variable
in the chain, with a separate plot per variable.
}

\note{
You can call this function directly, but it is more usually
called by the \code{plot.mcmc} function.
}

\seealso{
   \code{\link{densplot}}, \code{\link{plot.mcmc}}.
}
\keyword{hplot}

\eof
\name{varnames}
\alias{varnames}
\alias{varnames<-}
\alias{chanames}
\alias{chanames<-}
\title{Named dimensions of MCMC objects}

\usage{
varnames(x, allow.null=TRUE)
chanames(x, allow.null=TRUE)
varnames(x) <- value
chanames(x) <- value
}

\arguments{
\item{x}{an \code{mcmc} or \code{mcmc.list} object}
\item{allow.null}{Logical argument that determines whether the function may return NULL}
\item{value}{A character vector, or NULL}
}

\value{
   A character vector , or NULL.
}

\description{
   \code{varnames()} returns the variable names and \code{chanames}
   returns the chain names, or NULL if these are not set.  

   If \code{allow.null = FALSE} then \code{NULL} values will be
   replaced with canonical names.
}

\seealso{
   \code{\link{mcmc}},
   \code{\link{mcmc.list}}.
}
\keyword{manip}

\eof
\name{window.mcmc}
\alias{window.mcmc}
\alias{window.mcmc.list}
\title{Time windows for mcmc objects}

\usage{
\method{window}{mcmc}(x, start, end, thin, ...)
}

\arguments{
   \item{x}{an mcmc object}
   \item{start}{the first iteration of interest}
   \item{end}{the last iteration of interest}
   \item{thin}{the required interval between successive samples}
   \item{...}{futher arguments for future methods}
 }

\description{
   \code{window.mcmc} is a method for \code{mcmc} objects which is
   normally called by the generic function \code{window}

   In addition to the generic parameters, \code{start} and \code{end}
   the additional parameter \code{thin} may be used to thin out the
   Markov chain. Setting thin=k selects every kth iteration starting
   with the first. Note that the value of \code{thin} is \emph{absolute}
   not relative. The value supplied given to the parameter \code{thin}
   must be a multiple of \code{thin(x)}.

   Values of \code{start}, \code{end} and \code{thin} which are inconsistent
   with \code{x} are ignored, but a warning message is issued.
}

\seealso{
   \code{\link{window}}, \code{\link{thin}}.
}
\keyword{ts}

\eof
